@@ -20,4 +20,11 @@ class AlertFactory:
         if verbose:
             log.print_normal(f"Attempting to create {alert_type} alerter")
 
-        return T.cast(Alerter, alert_class_type(args.webhook_url))
+        # Handle different alert types with their specific parameters
+        if alert_type == AlertType.DISCORD:
+            # Discord requires both webhook_url and title
+            title = getattr(args, "title", "Alert")
+            return T.cast(Alerter, alert_class_type(webhook_url=args.webhook_url, title=title))
+
+        # Slack and Mock only need webhook_url
+        return T.cast(Alerter, alert_class_type(webhook_url=args.webhook_url))
